=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-02-08 14:58:38 +0000
+++ bzrlib/builtins.py	2007-02-09 15:56:49 +0000
@@ -2333,6 +2333,7 @@
             merge_type = _mod_merge.Merge3Merger
 
         tree = WorkingTree.open_containing(u'.')[0]
+        change_reporter = delta.ChangeReporter(tree.inventory)
 
         if branch is not None:
             try:
@@ -2341,7 +2342,7 @@
                 pass # Continue on considering this url a Branch
             else:
                 conflicts = merge_bundle(reader, tree, not force, merge_type,
-                                            reprocess, show_base)
+                                         reprocess, show_base, change_reporter)
                 if conflicts == 0:
                     return 0
                 else:
@@ -2400,7 +2401,9 @@
                     reprocess=reprocess,
                     show_base=show_base,
                     pull=pull,
-                    pb=pb, file_list=interesting_files)
+                    pb=pb,
+                    file_list=interesting_files,
+                    change_reporter=change_reporter)
             finally:
                 pb.finished()
             if conflict_count != 0:
@@ -3058,7 +3061,8 @@
                   merge_type=None,
                   file_list=None, show_base=False, reprocess=False,
                   pull=False,
-                  pb=DummyProgress()):
+                  pb=DummyProgress(),
+                  change_reporter=None):
     """Merge changes into a tree.
 
     base_revision
@@ -3102,7 +3106,7 @@
         raise errors.BzrCommandError("Cannot do conflict reduction and show base.")
     try:
         merger = _mod_merge.Merger(this_tree.branch, this_tree=this_tree,
-                                   pb=pb)
+                                   pb=pb, change_reporter=change_reporter)
         merger.pp = ProgressPhase("Merge phase", 5, pb)
         merger.pp.next_phase()
         merger.check_basis(check_clean)

=== modified file 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/bundle/apply_bundle.py	2006-10-05 05:37:25 +0000
+++ bzrlib/bundle/apply_bundle.py	2007-02-09 15:56:49 +0000
@@ -42,14 +42,15 @@
 
 
 def merge_bundle(reader, tree, check_clean, merge_type, 
-                    reprocess, show_base):
+                    reprocess, show_base, change_reporter=None):
     """Merge a revision bundle into the current tree."""
     pb = bzrlib.ui.ui_factory.nested_progress_bar()
     try:
         pp = ProgressPhase("Merge phase", 6, pb)
         pp.next_phase()
         install_bundle(tree.branch.repository, reader)
-        merger = Merger(tree.branch, this_tree=tree, pb=pb)
+        merger = Merger(tree.branch, this_tree=tree, pb=pb,
+                        change_reporter=change_reporter)
         merger.pp = pp
         merger.pp.next_phase()
         merger.check_basis(check_clean, require_commits=False)

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2007-02-01 15:40:07 +0000
+++ bzrlib/merge.py	2007-02-09 15:56:49 +0000
@@ -87,7 +87,7 @@
 
 class Merger(object):
     def __init__(self, this_branch, other_tree=None, base_tree=None, 
-                 this_tree=None, pb=DummyProgress()):
+                 this_tree=None, pb=DummyProgress(), change_reporter=None):
         object.__init__(self)
         assert this_tree is not None, "this_tree is required"
         self.this_branch = this_branch
@@ -105,7 +105,7 @@
         self.reprocess = False
         self._pb = pb 
         self.pp = None
-
+        self.change_reporter = change_reporter
 
     def revision_tree(self, revision_id):
         return self.this_branch.repository.revision_tree(revision_id)
@@ -268,7 +268,9 @@
         elif self.show_base:
             raise BzrError("Showing base is not supported for this"
                                   " merge type. %s" % self.merge_type)
-        merge = self.merge_type(pb=self._pb, **kwargs)
+        merge = self.merge_type(pb=self._pb,
+                                change_reporter=self.change_reporter,
+                                **kwargs)
         if len(merge.cooked_conflicts) == 0:
             if not self.ignore_zero:
                 note("All changes applied successfully.")
@@ -356,7 +358,7 @@
 
     def __init__(self, working_tree, this_tree, base_tree, other_tree, 
                  interesting_ids=None, reprocess=False, show_base=False,
-                 pb=DummyProgress(), pp=None):
+                 pb=DummyProgress(), pp=None, change_reporter=None):
         """Initialize the merger object and perform the merge."""
         object.__init__(self)
         self.this_tree = working_tree
@@ -368,6 +370,7 @@
         self.show_base = show_base
         self.pb = pb
         self.pp = pp
+        self.change_reporter = change_reporter
         if self.pp is None:
             self.pp = ProgressPhase("Merge phase", 3, self.pb)
 
@@ -396,6 +399,9 @@
                 fs_conflicts = resolve_conflicts(self.tt, child_pb)
             finally:
                 child_pb.finished()
+            if change_reporter is not None:
+                import delta
+                delta.report_changes(self.tt._iter_changes(), change_reporter)
             self.cook_conflicts(fs_conflicts)
             for conflict in self.cooked_conflicts:
                 warning(conflict)

